
function [M] = simpulse(b1,gz,dt,Morig,z,df,gamma);

% function [M] = simpulse(b1,gz,dt,Morig,z,df,gamma);
%
% Simulates an RF pulse described by
%   b1 - RF pulse (in Gauss)
%   gz - Z Gradient (in Gauss/cm)
%   dt - sampling period (in ms)
% for a given spin described by
%   Morig - original magnetization (usually [0;0;1])
%   z - z position (in cm)
%   df - off-resonant frequency (in Hz)
% gamma - 26.752 (in rad/ms/G)

if (exist('gamma')~=1) gamma = 26.752; end;

M = Morig;
for t=1:length(b1);
  R = zrot(-angle(b1(t)))*xrot(gamma*abs(b1(t))*dt)*zrot(angle(b1(t)));
  M = R * M;
  M = zrot(2*pi*df*dt*10^-3) * M;
  M = zrot(gamma*gz(t)*z*dt) * M;
end;

